==> activity-center-api-0.9.1.101-zbq-20190107.025728-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/ResourceLocationDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;
import java.util.List;

/**
 * 资源位
 *
 * @author weny.cai
 * @date 2018/11/30 10:51
 **/
public class ResourceLocationDto implements Serializable {

    private Long id;

    private Long groupId;

    private String resourceName;

    private Integer advertType;

    private String startDate;

    private String endDate;

    private Integer putState;

    private Integer switchState;

    private String posDesc;

    private Integer posType;

    private Integer budgetType;

    private Double dayBudget;

    private String payType;

    private List<ResourceTimeDto> timeDtos;

    private List<Long> posIds;

    private PopularGroupDto popularGroupDto;

    private Integer exposurePv;

    private Integer clickPv;

    private String price;

    private String clickRate;

    private String agvPrice;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getGroupId() {
        return groupId;
    }

    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Integer getPutState() {
        return putState;
    }

    public void setPutState(Integer putState) {
        this.putState = putState;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public String getPosDesc() {
        return posDesc;
    }

    public void setPosDesc(String posDesc) {
        this.posDesc = posDesc;
    }

    public Integer getPosType() {
        return posType;
    }

    public void setPosType(Integer posType) {
        this.posType = posType;
    }

    public Integer getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(Integer budgetType) {
        this.budgetType = budgetType;
    }

    public Double getDayBudget() {
        return dayBudget;
    }

    public void setDayBudget(Double dayBudget) {
        this.dayBudget = dayBudget;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public List<ResourceTimeDto> getTimeDtos() {
        return timeDtos;
    }

    public void setTimeDtos(List<ResourceTimeDto> timeDtos) {
        this.timeDtos = timeDtos;
    }

    public List<Long> getPosIds() {
        return posIds;
    }

    public void setPosIds(List<Long> posIds) {
        this.posIds = posIds;
    }

    public PopularGroupDto getPopularGroupDto() {
        return popularGroupDto;
    }

    public void setPopularGroupDto(PopularGroupDto popularGroupDto) {
        this.popularGroupDto = popularGroupDto;
    }

    public Integer getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Integer exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Integer getClickPv() {
        return clickPv;
    }

    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        this.price = price;
    }

    public String getClickRate() {
        return clickRate;
    }

    public void setClickRate(String clickRate) {
        this.clickRate = clickRate;
    }

    public String getAgvPrice() {
        return agvPrice;
    }

    public void setAgvPrice(String agvPrice) {
        this.agvPrice = agvPrice;
    }
}

==> activity-center-api-0.9.5.1-zbq-20190318.081832-5-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/ResourceLocationDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;
import java.util.List;

/**
 * 资源位
 *
 * @author weny.cai
 * @date 2018/11/30 10:51
 **/
public class ResourceLocationDto implements Serializable {

    private Long id;

    private Long groupId;

    private String resourceName;

    private Integer advertType;

    private Integer putDateState;

    private String startDate;

    private String endDate;

    private Integer putState;

    private Integer switchState;

    private String posDesc;

    private Integer posType;

    private Integer budgetType;

    private Double dayBudget;

    private String payType;

    private List<ResourceTimeDto> timeDtos;

    private List<String> posIds;

    private List<ResourcePicSpecificationDto> picSpecificationDtos;

    private PopularGroupDto popularGroupDto;

    private Integer exposurePv;

    private Integer clickPv;

    private String price;

    private String clickRate;

    private String agvPrice;

    /**
     * 创意投放方式
     */
    private Integer putType;

    private Integer feedType;

    private Integer styleType;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getGroupId() {
        return groupId;
    }

    public void setGroupId(Long groupId) {
        this.groupId = groupId;
    }

    public String getResourceName() {
        return resourceName;
    }

    public void setResourceName(String resourceName) {
        this.resourceName = resourceName;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public Integer getPutDateState() {
        return putDateState;
    }

    public void setPutDateState(Integer putDateState) {
        this.putDateState = putDateState;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Integer getPutState() {
        return putState;
    }

    public void setPutState(Integer putState) {
        this.putState = putState;
    }

    public Integer getSwitchState() {
        return switchState;
    }

    public void setSwitchState(Integer switchState) {
        this.switchState = switchState;
    }

    public String getPosDesc() {
        return posDesc;
    }

    public void setPosDesc(String posDesc) {
        this.posDesc = posDesc;
    }

    public Integer getPosType() {
        return posType;
    }

    public void setPosType(Integer posType) {
        this.posType = posType;
    }

    public Integer getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(Integer budgetType) {
        this.budgetType = budgetType;
    }

    public Double getDayBudget() {
        return dayBudget;
    }

    public void setDayBudget(Double dayBudget) {
        this.dayBudget = dayBudget;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public List<ResourceTimeDto> getTimeDtos() {
        return timeDtos;
    }

    public void setTimeDtos(List<ResourceTimeDto> timeDtos) {
        this.timeDtos = timeDtos;
    }

    public List<String> getPosIds() {
        return posIds;
    }

    public void setPosIds(List<String> posIds) {
        this.posIds = posIds;
    }

    public List<ResourcePicSpecificationDto> getPicSpecificationDtos() {
        return picSpecificationDtos;
    }

    public void setPicSpecificationDtos(List<ResourcePicSpecificationDto> picSpecificationDtos) {
        this.picSpecificationDtos = picSpecificationDtos;
    }

    public PopularGroupDto getPopularGroupDto() {
        return popularGroupDto;
    }

    public void setPopularGroupDto(PopularGroupDto popularGroupDto) {
        this.popularGroupDto = popularGroupDto;
    }

    public Integer getExposurePv() {
        return exposurePv;
    }

    public void setExposurePv(Integer exposurePv) {
        this.exposurePv = exposurePv;
    }

    public Integer getClickPv() {
        return clickPv;
    }

    public void setClickPv(Integer clickPv) {
        this.clickPv = clickPv;
    }

    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        this.price = price;
    }

    public String getClickRate() {
        return clickRate;
    }

    public void setClickRate(String clickRate) {
        this.clickRate = clickRate;
    }

    public String getAgvPrice() {
        return agvPrice;
    }

    public void setAgvPrice(String agvPrice) {
        this.agvPrice = agvPrice;
    }

    public Integer getPutType() {
        return putType;
    }

    public void setPutType(Integer putType) {
        this.putType = putType;
    }

    public Integer getFeedType() {
        return feedType;
    }

    public void setFeedType(Integer feedType) {
        this.feedType = feedType;
    }

    public Integer getStyleType() {
        return styleType;
    }

    public void setStyleType(Integer styleType) {
        this.styleType = styleType;
    }
}
